@@ -6,17 +6,20 @@ impl Mul<&Value> for Value {
     type Output = Value;
     fn op_mul(self, rhs: &Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() * rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() * rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() * rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s * rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s * rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s * rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -26,17 +29,20 @@ impl Mul<&&Value> for Value {
     type Output = Value;
     fn op_mul(self, rhs: &&Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() * rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() * rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() * rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s * rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s * rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s * rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -46,17 +52,20 @@ impl Mul<Value> for Value {
     type Output = Value;
     fn op_mul(self, rhs: Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() * rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() * rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() * rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s * rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s * rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s * rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -66,17 +75,20 @@ impl Mul<&Value> for &Value {
     type Output = Value;
     fn op_mul(self, rhs: &Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() * rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() * rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() * rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s * rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s * rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s * rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -86,17 +98,20 @@ impl Mul<&&Value> for &Value {
     type Output = Value;
     fn op_mul(self, rhs: &&Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() * rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() * rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() * rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s * rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s * rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s * rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -106,34 +121,36 @@ impl Mul<Value> for &Value {
     type Output = Value;
     fn op_mul(self, rhs: Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() * rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() * rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() * rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int32(s * rhs);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s * rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s * rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
 }
 
 
-
-fn op_mul_i64(value: &Value, other: i64) -> i64 {
-    value.as_i64().unwrap_or_default() * other
+fn op_mul_i32(value: &Value, other: i32) -> i32 {
+    value.i32() * other
 }
 
-fn op_mul_u64(value: &Value, other: u64) -> u64 {
-    value.as_u64().unwrap_or_default() * other
+fn op_mul_i64(value: &Value, other: i64) -> i64 {
+    value.i64() * other
 }
 
 fn op_mul_f64(value: &Value, other: f64) -> f64 {
-    value.as_f64().unwrap_or_default() * other
+    value.f64() * other
 }
 
 macro_rules! impl_numeric_mul {
@@ -187,7 +204,6 @@ macro_rules! impl_numeric_mul {
 
 impl_numeric_mul! {
     op_mul_i64[i8 i16 i32 i64 isize] -> i64
-    op_mul_u64[u8 u16 u32 u64 usize] -> u64
     op_mul_f64[f32 f64] -> f64
 }
 
@@ -226,5 +242,4 @@ impl Mul<&$ty> for &$ty{
 }
 
 mul_self!([i8 i16 i32 i64 isize]);
-mul_self!([u8 u16 u32 u64 usize]);
 mul_self!([f32 f64]);
\ No newline at end of file
