@@ -8,17 +8,20 @@ impl Sub<&Value> for Value {
     type Output = Value;
     fn op_sub(self, rhs: &Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() - rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() - rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() - rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int64((s - rhs) as i64);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s - rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s - rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -28,17 +31,20 @@ impl Sub<&&Value> for Value {
     type Output = Value;
     fn op_sub(self, rhs: &&Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() - rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() - rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() - rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int64((s - rhs) as i64);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s - rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s - rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -48,17 +54,20 @@ impl Sub<Value> for Value {
     type Output = Value;
     fn op_sub(self, rhs: Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() - rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() - rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() - rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int64((s - rhs) as i64);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s - rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s - rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -68,17 +77,20 @@ impl Sub<&Value> for &Value {
     type Output = Value;
     fn op_sub(self, rhs: &Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() - rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() - rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() - rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int64((s - rhs) as i64);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s - rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s - rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -88,17 +100,20 @@ impl Sub<&&Value> for &Value {
     type Output = Value;
     fn op_sub(self, rhs: &&Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() - rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() - rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() - rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int64((s - rhs) as i64);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s - rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s - rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -108,17 +123,20 @@ impl Sub<Value> for &Value {
     type Output = Value;
     fn op_sub(self, rhs: Value) -> Self::Output {
         return match self {
-            serde_json::Value::Number(s) => {
-                if s.is_i64() {
-                    serde_json::json!(s.as_i64().unwrap_or_default() - rhs.as_i64().unwrap_or_default())
-                } else if s.is_f64() {
-                    serde_json::json!(s.as_f64().unwrap_or_default() - rhs.as_f64().unwrap_or_default())
-                } else {
-                    serde_json::json!(s.as_u64().unwrap_or_default() - rhs.as_u64().unwrap_or_default())
-                }
+            Value::Int32(s) => {
+                let rhs = rhs.i32();
+                return Value::Int64((s - rhs) as i64);
+            }
+            Value::Int64(s) => {
+                let rhs = rhs.i64();
+                return Value::Int64(s - rhs);
+            }
+            Value::Double(s) => {
+                let rhs = rhs.as_f64().unwrap_or_default();
+                return Value::Double(s - rhs);
             }
             _ => {
-                return serde_json::Value::Null;
+                return Value::Null;
             }
         };
     }
@@ -128,28 +146,20 @@ impl Sub<Value> for &Value {
 
 
 fn op_sub_i64(value: &Value, other: i64) -> i64 {
-    value.as_i64().unwrap_or_default() - other
-}
-
-fn op_sub_u64(value: &Value, other: u64) -> u64 {
-    value.as_u64().unwrap_or_default() - other
+    value.i64() - other
 }
 
 fn op_sub_f64(value: &Value, other: f64) -> f64 {
-    value.as_f64().unwrap_or_default() - other
+    value.f64() - other
 }
 
 
 fn op_sub_i64_value(value: &Value, other: i64) -> i64 {
-    other - value.as_i64().unwrap_or_default()
-}
-
-fn op_sub_u64_value(value: &Value, other: u64) -> u64 {
-    other - value.as_u64().unwrap_or_default()
+    other - value.i64()
 }
 
 fn op_sub_f64_value(value: &Value, other: f64) -> f64 {
-    other - value.as_f64().unwrap_or_default()
+    other - value.f64()
 }
 
 
@@ -196,7 +206,6 @@ macro_rules! impl_numeric_sub {
 
 impl_numeric_sub! {
     op_sub_i64,op_sub_i64_value[i8 i16 i32 i64 isize] -> i64
-    op_sub_u64,op_sub_u64_value[u8 u16 u32 u64 usize] -> u64
     op_sub_f64,op_sub_f64_value[f32 f64] -> f64
 }
 
@@ -234,5 +243,4 @@ impl Sub<&$ty> for &$ty{
 }
 
 sub_self!([i8 i16 i32 i64 isize]);
-sub_self!([u8 u16 u32 u64 usize]);
 sub_self!([f32 f64]);
\ No newline at end of file
